@@ -5,7 +5,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* GSL implementation of BLAS operations for vectors and dense
@@ -1627,13 +1627,14 @@ gsl_blas_ssyrk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans, float alpha,
 {
   const size_t M = C->size1;
   const size_t N = C->size2;
+  const size_t J = (Trans == CblasNoTrans) ? A->size1 : A->size2;
   const size_t K = (Trans == CblasNoTrans) ? A->size2 : A->size1;
 
   if (M != N)
     {
       GSL_ERROR ("matrix C must be square", GSL_ENOTSQR);
     }
-  else if (N != K)
+  else if (N != J)
     {
       GSL_ERROR ("invalid length", GSL_EBADLEN);
     }
@@ -1650,13 +1651,14 @@ gsl_blas_dsyrk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans, double alpha,
 {
   const size_t M = C->size1;
   const size_t N = C->size2;
+  const size_t J = (Trans == CblasNoTrans) ? A->size1 : A->size2;
   const size_t K = (Trans == CblasNoTrans) ? A->size2 : A->size1;
 
   if (M != N)
     {
       GSL_ERROR ("matrix C must be square", GSL_ENOTSQR);
     }
-  else if (N != K)
+  else if (N != J)
     {
       GSL_ERROR ("invalid length", GSL_EBADLEN);
     }
@@ -1676,13 +1678,14 @@ gsl_blas_csyrk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans,
 {
   const size_t M = C->size1;
   const size_t N = C->size2;
+  const size_t J = (Trans == CblasNoTrans) ? A->size1 : A->size2;
   const size_t K = (Trans == CblasNoTrans) ? A->size2 : A->size1;
 
   if (M != N)
     {
       GSL_ERROR ("matrix C must be square", GSL_ENOTSQR);
     }
-  else if (N != K)
+  else if (N != J)
     {
       GSL_ERROR ("invalid length", GSL_EBADLEN);
     }
@@ -1701,13 +1704,14 @@ gsl_blas_zsyrk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans,
 {
   const size_t M = C->size1;
   const size_t N = C->size2;
+  const size_t J = (Trans == CblasNoTrans) ? A->size1 : A->size2;
   const size_t K = (Trans == CblasNoTrans) ? A->size2 : A->size1;
 
   if (M != N)
     {
       GSL_ERROR ("matrix C must be square", GSL_ENOTSQR);
     }
-  else if (N != K)
+  else if (N != J)
     {
       GSL_ERROR ("invalid length", GSL_EBADLEN);
     }
@@ -1727,13 +1731,14 @@ gsl_blas_cherk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans, float alpha,
 {
   const size_t M = C->size1;
   const size_t N = C->size2;
+  const size_t J = (Trans == CblasNoTrans) ? A->size1 : A->size2;
   const size_t K = (Trans == CblasNoTrans) ? A->size2 : A->size1;
 
   if (M != N)
     {
       GSL_ERROR ("matrix C must be square", GSL_ENOTSQR);
     }
-  else if (N != K)
+  else if (N != J)
     {
       GSL_ERROR ("invalid length", GSL_EBADLEN);
     }
@@ -1751,13 +1756,14 @@ gsl_blas_zherk (CBLAS_UPLO_t Uplo, CBLAS_TRANSPOSE_t Trans, double alpha,
 {
   const size_t M = C->size1;
   const size_t N = C->size2;
+  const size_t J = (Trans == CblasNoTrans) ? A->size1 : A->size2;
   const size_t K = (Trans == CblasNoTrans) ? A->size2 : A->size1;
 
   if (M != N)
     {
       GSL_ERROR ("matrix C must be square", GSL_ENOTSQR);
     }
-  else if (N != K)
+  else if (N != J)
     {
       GSL_ERROR ("invalid length", GSL_EBADLEN);
     }
