@@ -68,7 +68,7 @@ gsl_eigen_genv_alloc(const size_t n)
                       GSL_EINVAL);
     }
 
-  w = calloc (1, sizeof (gsl_eigen_genv_workspace));
+  w = (gsl_eigen_genv_workspace *) calloc (1, sizeof (gsl_eigen_genv_workspace));
 
   if (w == 0)
     {
