@@ -1,3 +1,22 @@
+/* linalg/svdstep.c 
+ *
+ * Copyright (C) 2007 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
+
 static void
 chop_small_elements (gsl_vector * d, gsl_vector * f)
 {
@@ -54,7 +73,31 @@ static void
 create_schur (double d0, double f0, double d1, double * c, double * s)
 {
   double apq = 2.0 * d0 * f0;
-  
+
+  if (d0 == 0 || f0 == 0)
+    {
+      *c = 1.0;
+      *s = 0.0;
+      return;
+    }
+
+  /* Check if we need to rescale to avoid underflow/overflow */
+  if (fabs(d0) < GSL_SQRT_DBL_MIN || fabs(d0) > GSL_SQRT_DBL_MAX
+      || fabs(f0) < GSL_SQRT_DBL_MIN || fabs(f0) > GSL_SQRT_DBL_MAX
+      || fabs(d1) < GSL_SQRT_DBL_MIN || fabs(d1) > GSL_SQRT_DBL_MAX)
+    {
+      double scale;
+      int d0_exp, f0_exp;
+      frexp(d0, &d0_exp);
+      frexp(f0, &f0_exp);
+      /* Bring |d0*f0| into the range GSL_DBL_MIN to GSL_DBL_MAX */
+      scale = ldexp(1.0, -(d0_exp + f0_exp)/4);
+      d0 *= scale;
+      f0 *= scale;
+      d1 *= scale;
+      apq = 2.0 * d0 * f0;
+    }
+
   if (apq != 0.0)
     {
       double t;
@@ -147,9 +190,9 @@ svd2 (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
   else
     {
       /* Make columns orthogonal, A = [d0, f0; 0, d1] * G */
-      
+
       create_schur (d0, f0, d1, &c, &s);
-      
+
       /* compute B <= B G */
       
       a11 = c * d0 - s * f0;
@@ -211,11 +254,13 @@ svd2 (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
 static void
 chase_out_intermediate_zero (gsl_vector * d, gsl_vector * f, gsl_matrix * U, size_t k0)
 {
+#if !USE_BLAS
   const size_t M = U->size1;
+#endif
   const size_t n = d->size;
   double c, s;
   double x, y;
-  size_t i, k;
+  size_t k;
 
   x = gsl_vector_get (f, k0);
   y = gsl_vector_get (d, k0+1);
@@ -225,14 +270,26 @@ chase_out_intermediate_zero (gsl_vector * d, gsl_vector * f, gsl_matrix * U, siz
       create_givens (y, -x, &c, &s);
       
       /* Compute U <= U G */
-      
-      for (i = 0; i < M; i++)
-        {
-          double Uip = gsl_matrix_get (U, i, k0);
-          double Uiq = gsl_matrix_get (U, i, k + 1);
-          gsl_matrix_set (U, i, k0, c * Uip - s * Uiq);
-          gsl_matrix_set (U, i, k + 1, s * Uip + c * Uiq);
-        }
+
+#ifdef USE_BLAS
+      {
+        gsl_vector_view Uk0 = gsl_matrix_column(U,k0);
+        gsl_vector_view Ukp1 = gsl_matrix_column(U,k+1);
+        gsl_blas_drot(&Uk0.vector, &Ukp1.vector, c, -s);
+      }
+#else
+      {
+        size_t i;
+
+        for (i = 0; i < M; i++)
+          {
+            double Uip = gsl_matrix_get (U, i, k0);
+            double Uiq = gsl_matrix_get (U, i, k + 1);
+            gsl_matrix_set (U, i, k0, c * Uip - s * Uiq);
+            gsl_matrix_set (U, i, k + 1, s * Uip + c * Uiq);
+          }
+      }
+#endif
       
       /* compute B <= G^T B */
       
@@ -255,28 +312,42 @@ chase_out_intermediate_zero (gsl_vector * d, gsl_vector * f, gsl_matrix * U, siz
 static void
 chase_out_trailing_zero (gsl_vector * d, gsl_vector * f, gsl_matrix * V)
 {
+#if !USE_BLAS
   const size_t N = V->size1;
+#endif
   const size_t n = d->size;
   double c, s;
   double x, y;
-  size_t i, k;
+  size_t k;
 
   x = gsl_vector_get (d, n - 2);
   y = gsl_vector_get (f, n - 2);
 
-  for (k = n - 1; k > 0 && k--;)
+  for (k = n - 1; k-- > 0;)
     {
       create_givens (x, y, &c, &s);
 
       /* Compute V <= V G where G = [c, s ; -s, c] */
-      
-      for (i = 0; i < N; i++)
-        {
-          double Vip = gsl_matrix_get (V, i, k);
-          double Viq = gsl_matrix_get (V, i, n - 1);
-          gsl_matrix_set (V, i, k, c * Vip - s * Viq);
-          gsl_matrix_set (V, i, n - 1, s * Vip + c * Viq);
-        }
+
+#ifdef USE_BLAS
+      {
+        gsl_vector_view Vp = gsl_matrix_column(V,k);
+        gsl_vector_view Vq = gsl_matrix_column(V,n-1);
+        gsl_blas_drot(&Vp.vector, &Vq.vector, c, -s);
+      }
+#else
+      {
+        size_t i;
+   
+        for (i = 0; i < N; i++)
+          {
+            double Vip = gsl_matrix_get (V, i, k);
+            double Viq = gsl_matrix_get (V, i, n - 1);
+            gsl_matrix_set (V, i, k, c * Vip - s * Viq);
+            gsl_matrix_set (V, i, n - 1, s * Vip + c * Viq);
+          }
+      }
+#endif
 
       /* compute B <= B G */
       
@@ -299,8 +370,10 @@ chase_out_trailing_zero (gsl_vector * d, gsl_vector * f, gsl_matrix * V)
 static void
 qrstep (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
 {
+#if !USE_BLAS
   const size_t M = U->size1;
   const size_t N = V->size1;
+#endif
   const size_t n = d->size;
   double y, z;
   double ak, bk, zk, ap, bp, aq, bq;
@@ -378,6 +451,13 @@ qrstep (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
 
       /* Compute V <= V G */
 
+#ifdef USE_BLAS
+      {
+        gsl_vector_view Vk = gsl_matrix_column(V,k);
+        gsl_vector_view Vkp1 = gsl_matrix_column(V,k+1);
+        gsl_blas_drot(&Vk.vector, &Vkp1.vector, c, -s);
+      }
+#else
       for (i = 0; i < N; i++)
         {
           double Vip = gsl_matrix_get (V, i, k);
@@ -385,6 +465,7 @@ qrstep (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
           gsl_matrix_set (V, i, k, c * Vip - s * Viq);
           gsl_matrix_set (V, i, k + 1, s * Vip + c * Viq);
         }
+#endif
 
       /* compute B <= B G */
 
@@ -425,6 +506,13 @@ qrstep (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
 
       /* Compute U <= U G */
 
+#ifdef USE_BLAS
+      {
+        gsl_vector_view Uk = gsl_matrix_column(U,k);
+        gsl_vector_view Ukp1 = gsl_matrix_column(U,k+1);
+        gsl_blas_drot(&Uk.vector, &Ukp1.vector, c, -s);
+      }
+#else
       for (i = 0; i < M; i++)
         {
           double Uip = gsl_matrix_get (U, i, k);
@@ -432,6 +520,7 @@ qrstep (gsl_vector * d, gsl_vector * f, gsl_matrix * U, gsl_matrix * V)
           gsl_matrix_set (U, i, k, c * Uip - s * Uiq);
           gsl_matrix_set (U, i, k + 1, s * Uip + c * Uiq);
         }
+#endif
 
       /* compute B <= G^T B */
 
