@@ -1,10 +1,10 @@
 /* matrix/test.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -19,7 +19,7 @@
 
 #include <config.h>
 
-#if !GSL_RANGE_CHECK
+#if (!GSL_RANGE_CHECK) && defined(HAVE_INLINE)
 #undef GSL_RANGE_CHECK
 #define GSL_RANGE_CHECK 1
 #endif
@@ -182,6 +182,7 @@ main (void)
   test_complex_float_binary ();
   test_complex_long_double_binary ();
 
+#if GSL_RANGE_CHECK
   gsl_set_error_handler (&my_error_handler);
 
   test_trap ();
@@ -198,6 +199,7 @@ main (void)
   test_complex_trap ();
   test_complex_float_trap ();
   test_complex_long_double_trap ();
+#endif
 
   test_complex_arith ();
   test_complex_float_arith ();
