@@ -71,6 +71,8 @@
 #define NEW_COORD(s,i) ((s)->xin[(i)])
 #define VALUE(s,i,j) ((s)->d[(i)*(s)->dim + (j)])
 
+#define USE_ORIGINAL_CHISQ_FORMULA 0
+
 /* predeclare functions */
 
 typedef int coord;
@@ -149,6 +151,7 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
       state->chi_sum = 0;
       state->it_num = 1;
       state->samples = 0;
+      state->chisq = 0;
     }
 
   if (state->stage <= 2)
@@ -212,13 +215,11 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
   cum_int = 0.0;
   cum_sig = 0.0;
 
-  state->chisq = 0.0;
-
   for (it = 0; it < state->iterations; it++)
     {
       double intgrl = 0.0, intgrl_sq = 0.0;
-      double sig = 0.0;
-      double wgt;
+      double tss = 0.0;
+      double wgt, var, sig;
       size_t calls_per_box = state->calls_per_box;
       double jacbin = state->jac;
       double *x = state->x;
@@ -231,18 +232,19 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
       
       do
         {
-          double m = 0, q = 0;
+          volatile double m = 0, q = 0;
           double f_sq_sum = 0.0;
 
           for (k = 0; k < calls_per_box; k++)
             {
-              double fval, bin_vol;
+              volatile double fval;
+              double bin_vol;
 
               random_point (x, bin, &bin_vol, state->box, xl, xu, state, r);
 
               fval = jacbin * bin_vol * GSL_MONTE_FN_EVAL (f, x);
 
-              /* recurrence for mean and variance */
+              /* recurrence for mean and variance (sum of squares) */
 
               {
                 double d = fval - m;
@@ -259,9 +261,9 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
 
           intgrl += m * calls_per_box;
 
-          f_sq_sum = q * calls_per_box ;
+          f_sq_sum = q * calls_per_box;
 
-          sig += f_sq_sum ;
+          tss += f_sq_sum;
 
           if (state->mode == GSL_VEGAS_MODE_STRATIFIED)
             {
@@ -272,11 +274,11 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
 
       /* Compute final results for this iteration   */
 
-      sig = sig / (calls_per_box - 1.0)  ;
+      var = tss / (calls_per_box - 1.0)  ;
 
-      if (sig > 0) 
+      if (var > 0) 
         {
-          wgt = 1.0 / sig;
+          wgt = 1.0 / var;
         }
       else if (state->sum_wgts > 0) 
         {
@@ -289,11 +291,18 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
         
      intgrl_sq = intgrl * intgrl;
 
+     sig = sqrt (var);
+
      state->result = intgrl;
-     state->sigma  = sqrt(sig);
+     state->sigma  = sig;
 
      if (wgt > 0.0)
        {
+         double sum_wgts = state->sum_wgts;
+         double wtd_int_sum = state->wtd_int_sum;
+         double m = (sum_wgts > 0) ? (wtd_int_sum / sum_wgts) : 0;
+         double q = intgrl - m;
+
          state->samples++ ;
          state->sum_wgts += wgt;
          state->wtd_int_sum += intgrl * wgt;
@@ -302,11 +311,26 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
          cum_int = state->wtd_int_sum / state->sum_wgts;
          cum_sig = sqrt (1 / state->sum_wgts);
 
+#if USE_ORIGINAL_CHISQ_FORMULA
+/* This is the chisq formula from the original Lepage paper.  It
+   computes the variance from <x^2> - <x>^2 and can suffer from
+   catastrophic cancellations, e.g. returning negative chisq. */
          if (state->samples > 1)
            {
              state->chisq = (state->chi_sum - state->wtd_int_sum * cum_int) /
                (state->samples - 1.0);
            }
+#else
+/* The new formula below computes exactly the same quantity as above
+   but using a stable recurrence */
+         if (state->samples == 1) {
+           state->chisq = 0;
+         } else {
+           state->chisq *= (state->samples - 2.0);
+           state->chisq += (wgt / (1 + (wgt / sum_wgts))) * q * q;
+           state->chisq /= (state->samples - 1.0);
+         }
+#endif
        }
      else
        {
@@ -318,7 +342,7 @@ gsl_monte_vegas_integrate (gsl_monte_function * f,
       if (state->verbose >= 0)
         {
           print_res (state,
-                     state->it_num, intgrl, sqrt (sig), cum_int, cum_sig,
+                     state->it_num, intgrl, sig, cum_int, cum_sig,
                      state->chisq);
           if (it + 1 == state->iterations && state->verbose > 0)
             {
